@@ -1,7 +1,7 @@
-from .api_client import APIException
+from .api_client import APIException, APIClientBase
 from .auth_api import Authentication
 from .virt_api import Virtualization
 from .storage_api import Storage
 from .protection_api import Protection
 from .jobs_api import Jobs
-from .central_api import Central
\ No newline at end of file
+from .central_api import Central
